@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/servers/slapd/add.c,v 1.162.2.10 2004/04/12 18:20:12 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/add.c,v 1.162.2.11 2004/04/19 18:15:14 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2004 The OpenLDAP Foundation.
@@ -501,7 +501,7 @@ slap_mods2entry(
 				}
 
 			} else {
-				int		rc = LDAP_SUCCESS;
+				int	rc;
 				int match;
 
 				for ( i = 1; mods->sml_values[i].bv_val != NULL; i++ ) {
@@ -519,18 +519,19 @@ slap_mods2entry(
 								? &mods->sml_nvalues[j]
 								: &mods->sml_values[j],
 							text );
+
 						if ( rc == LDAP_SUCCESS && match == 0 ) {
 							/* value exists already */
 							snprintf( textbuf, textlen,
 								"%s: value #%d provided more than once",
 								mods->sml_desc->ad_cname.bv_val, j );
 							return LDAP_TYPE_OR_VALUE_EXISTS;
+
+						} else if ( rc != LDAP_SUCCESS ) {
+							return rc;
 						}
 					}
 				}
-				if ( rc != LDAP_SUCCESS ) {
-					return rc;
-				}
 			}
 		}
 
