@@ -1,5 +1,5 @@
 /* config.c - configuration file handling routines */
-/* $OpenLDAP: pkg/ldap/servers/slapd/config.c,v 1.228.2.10 2004/03/25 22:57:56 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/config.c,v 1.228.2.14 2004/04/15 20:45:28 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2004 The OpenLDAP Foundation.
@@ -54,7 +54,8 @@ struct slap_limits_set deflimit = {
 	0,
 	-1,				/* no limit on unchecked size */
 	0,				/* page limit */
-	0				/* hide number of entries left */
+	0,				/* hide number of entries left */
+	0				/* number of total entries returned by pagedResults equal to hard limit */
 };
 
 AccessControl	*global_acl = NULL;
@@ -73,11 +74,11 @@ char		*ldap_srvtab = "";
 char		**default_passwd_hash = NULL;
 int		cargc = 0, cargv_size = 0;
 char	**cargv;
-struct berval default_search_base = { 0, NULL };
-struct berval default_search_nbase = { 0, NULL };
+struct berval default_search_base = BER_BVNULL;
+struct berval default_search_nbase = BER_BVNULL;
 unsigned		num_subordinates = 0;
-struct berval global_schemadn = { 0, NULL };
-struct berval global_schemandn = { 0, NULL };
+struct berval global_schemadn = BER_BVNULL;
+struct berval global_schemandn = BER_BVNULL;
 
 ber_len_t sockbuf_max_incoming = SLAP_SB_MAX_INCOMING_DEFAULT;
 ber_len_t sockbuf_max_incoming_auth= SLAP_SB_MAX_INCOMING_AUTH;
@@ -960,7 +961,7 @@ read_config( const char *fname, int depth )
 				return 1;
 
 			} else {
-				be->be_flags |= SLAP_BFLAG_GLUE_SUBORDINATE;
+				SLAP_DBFLAGS(be) |= SLAP_DBFLAG_GLUE_SUBORDINATE;
 				num_subordinates++;
 			}
 
@@ -1801,12 +1802,25 @@ read_config( const char *fname, int depth )
 					    "a database definition.\n", fname, lineno, 0);
 #endif
 				return 1;
-			} else {
-				if ( add_syncrepl( be, cargv, cargc )) {
-					return 1;
-				}
+
+			} else if ( SLAP_SHADOW( be )) {
+#ifdef NEW_LOGGING
+				LDAP_LOG( CONFIG, INFO, 
+					"%s: line %d: syncrepl: database already shadowed.\n",
+					fname, lineno, 0);
+#else
+				Debug( LDAP_DEBUG_ANY,
+					"%s: line %d: syncrepl: database already shadowed.\n",
+					fname, lineno, 0);
+#endif
+				return 1;
+
+			} else if ( add_syncrepl( be, cargv, cargc )) {
+				return 1;
 			}
 
+			SLAP_DBFLAGS(be) |= ( SLAP_DBFLAG_SHADOW | SLAP_DBFLAG_SYNC_SHADOW );
+
 		/* list of replicas of the data in this backend (master only) */
 		} else if ( strcasecmp( cargv[0], "replica" ) == 0 ) {
 			if ( cargc < 2 ) {
@@ -2010,6 +2024,18 @@ read_config( const char *fname, int depth )
 #endif
 				return 1;
 
+			} else if ( SLAP_SHADOW(be) ) {
+#ifdef NEW_LOGGING
+				LDAP_LOG( CONFIG, INFO, 
+					"%s: line %d: updatedn: database already shadowed.\n",
+					fname, lineno, 0);
+#else
+				Debug( LDAP_DEBUG_ANY,
+					"%s: line %d: updatedn: database already shadowed.\n",
+					fname, lineno, 0);
+#endif
+				return 1;
+
 			} else {
 				struct berval dn;
 
@@ -2031,7 +2057,9 @@ read_config( const char *fname, int depth )
 #endif
 					return 1;
 				}
+
 			}
+			SLAP_DBFLAGS(be) |= ( SLAP_DBFLAG_SHADOW | SLAP_DBFLAG_SLURP_SHADOW );
 
 		} else if ( strcasecmp( cargv[0], "updateref" ) == 0 ) {
 			if ( cargc < 2 ) {
@@ -2059,14 +2087,14 @@ read_config( const char *fname, int depth )
 #endif
 				return 1;
 
-			} else if ( !be->be_update_ndn.bv_len ) {
+			} else if ( !SLAP_SHADOW(be) ) {
 #ifdef NEW_LOGGING
 				LDAP_LOG( CONFIG, INFO, "%s: line %d: "
-					"updateref line must come after updatedn.\n",
+					"updateref line must come after syncrepl or updatedn.\n",
 					fname, lineno , 0 );
 #else
 				Debug( LDAP_DEBUG_ANY, "%s: line %d: "
-					"updateref line must after updatedn.\n",
+					"updateref line must after syncrepl or updatedn.\n",
 				    fname, lineno, 0 );
 #endif
 				return 1;
@@ -2087,8 +2115,9 @@ read_config( const char *fname, int depth )
 
 			vals[0].bv_val = cargv[1];
 			vals[0].bv_len = strlen( vals[0].bv_val );
-			if( value_add( &be->be_update_refs, vals ) )
+			if( value_add( &be->be_update_refs, vals ) ) {
 				return LDAP_OTHER;
+			}
 
 		/* replication log file to which changes are appended */
 		} else if ( strcasecmp( cargv[0], "replogfile" ) == 0 ) {
@@ -2156,13 +2185,13 @@ read_config( const char *fname, int depth )
 			}
 			if ( strcasecmp( cargv[1], "on" ) == 0 ) {
 				if ( be ) {
-					be->be_flags &= ~SLAP_BFLAG_NOLASTMOD;
+					SLAP_DBFLAGS(be) &= ~SLAP_DBFLAG_NOLASTMOD;
 				} else {
 					lastmod = 1;
 				}
 			} else {
 				if ( be ) {
-					be->be_flags |= SLAP_BFLAG_NOLASTMOD;
+					SLAP_DBFLAGS(be) |= SLAP_DBFLAG_NOLASTMOD;
 				} else {
 					lastmod = 0;
 				}
@@ -2913,7 +2942,7 @@ add_syncrepl(
 			si->si_provideruri == NULL ? "(null)" : si->si_provideruri, 0, 0 );
 #endif
 		if ( !si->si_schemachecking ) {
-			be->be_flags |= SLAP_BFLAG_NO_SCHEMA_CHECK;
+			SLAP_DBFLAGS(be) |= SLAP_DBFLAG_NO_SCHEMA_CHECK;
 		}
 		si->si_be = be;
 		LDAP_STAILQ_INSERT_TAIL( &be->be_syncinfo, si, si_next );
