@@ -1,5 +1,5 @@
 /* schema_prep.c - load builtin schema */
-/* $OpenLDAP: pkg/ldap/servers/slapd/schema_prep.c,v 1.104.2.8 2004/01/17 19:32:20 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/schema_prep.c,v 1.104.2.9 2004/04/19 18:15:14 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2004 The OpenLDAP Foundation.
@@ -70,12 +70,12 @@ objectSubClassMatch(
 		}
 
 		/* desc form, return undefined */
-		return SLAPD_COMPARE_UNDEFINED;
+		return LDAP_INVALID_SYNTAX;
 	}
 
 	if ( oc == NULL ) {
 		/* unrecognized stored value */
-		return SLAPD_COMPARE_UNDEFINED;
+		return LDAP_INVALID_SYNTAX;
 	}
 
 	if( SLAP_MR_IS_VALUE_OF_ATTRIBUTE_SYNTAX( flags ) ) {
